%double_slit
% Plots Young's Double slit diffraction pattern. Assume infinitessimally
% thin slits.
%
% LAST UPDATED by Andy French 1/11/15

function double_slit

%Set wavelength /nm
%http://science-edu.larc.nasa.gov/EDDOCS/Wavelengths_for_Colors.html
lamda = 400;  %Violet
lamda = 445;  %Indigo
lamda = 475;  %Blue
lamda = 510;  %Green
lamda = 570;  %Yellow
lamda = 590;  %Orange
lamda = 650;  %Red

%Convert to metres
lamda = lamda*1e-9;

%Slit spacing /m
d = 5*lamda;

%Set fontsize
fsize = 18;

%Wavenumber /m^-1
k = 2*pi/lamda;

%Speed of light /ms^-1
c = 2.998e8;

%Calculate frequency /Hz
f = c/(lamda*1e-9);

%Set angles
theta = linspace( -pi/2,pi/2,1000);

%Determine intensity pattern amplitude variation with angle (i.e. range is
%the same)
I = ( cos( 0.5*k*d*sin(theta) ) ).^2;

%Determine angles of maxima
Nmax = floor( 0.5*k*d/pi );
theta_max = NaN(1,2*Nmax+1);
for n=1:2*Nmax+1
    nn = -Nmax-1+n;
    theta_max(n) = asin( 2*nn*pi/(k*d) );
    if imag(abs(theta_max(n)))>0
        theta_max(n) = NaN;
    end
end

%Plot intensity pattern (i.e. wave power)
plot( theta*180/pi, I );
hold on;
plot( (180/pi)*theta_max,zeros(1,2*Nmax+1),'r*' );
for n=1:2*Nmax+1
    plot( (180/pi)*[theta_max(n),theta_max(n)],[0,1],'r--');
end
xlabel( '\theta^o', 'fontsize',fsize );
ylabel('Normalized wave power','fontsize',fsize )
title(['Youngs Double slits: \lambda = ',num2str(lamda/1e-9),'nm,  d = ',num2str(d/lamda),'\lambda'],'fontsize',fsize);
xlim([-90,90])
grid on;
set(gca,'fontsize',fsize);
print( gcf,'double slits.png','-dpng','-r300');
close(gcf);

%End of code
